@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2014, Luis Pedro Coelho <luis@luispedro.org>
+# Copyright (C) 2008-2015, Luis Pedro Coelho <luis@luispedro.org>
 # vim: set ts=4 sts=4 sw=4 expandtab smartindent:
 # 
 # License: MIT (see COPYING file)
@@ -32,14 +32,12 @@ def bbox(img, border=None, as_slice=False):
         return np.array([], dtype=np.intp)
     r = _bbox.bbox(img)
     if border:
-        min1,max1,min2,max2 = r
-        min1 = max(0, min1-border)
-        min2 = max(0, min2-border)
-        max1 += border
-        max2 += border
-        r = min1,max1,min2,max2
+        r = r.reshape((-1, 2))
+        np.maximum(r.T[0] - border, 0, out=r.T[0])
+        r.T[1] += border
+        r = r.ravel()
     if as_slice:
-        return (slice(r[0],r[1]),slice(r[2],r[3]))
+        r = tuple([slice(s,e) for s,e in r.reshape((-1,2))])
     return r
 
 def croptobbox(img, border=None):
@@ -68,6 +66,6 @@ def croptobbox(img, border=None):
 
     This ensures that the result is always a sub-image of the input.
     """
-    min1,max1,min2,max2 = bbox(img, border=border)
-    return img[min1:max1,min2:max2]
+    sl = bbox(img, border=border, as_slice=True)
+    return img[sl]
 
