@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2014, Luis Pedro Coelho <luis@luispedro.org>
+# Copyright (C) 2010-2015, Luis Pedro Coelho <luis@luispedro.org>
 # vim: set ts=4 sts=4 sw=4 expandtab smartindent:
 #
 # License: MIT (see COPYING file)
@@ -25,6 +25,7 @@ __all__ = [
     'gaussian_filter',
     'wavelet_center',
     'wavelet_decenter',
+    'laplacian_2D'
     ]
 
 def convolve(f, weights, mode='reflect', cval=0.0, out=None, output=None):
@@ -63,7 +64,7 @@ def convolve(f, weights, mode='reflect', cval=0.0, out=None, output=None):
     return _convolve.convolve(f, weights, output, mode2int[mode])
 
 
-def convolve1d(f, weights, axis, mode='reflect', cval=0., out=None, output=None):
+def convolve1d(f, weights, axis, mode='reflect', cval=0., out=None):
     '''
     convolved = convolve1d(f, weights, axis, mode='reflect', cval=0.0, out={new array})
 
@@ -109,7 +110,7 @@ def convolve1d(f, weights, axis, mode='reflect', cval=0., out=None, output=None)
         oshape = f.shape
         f = f.transpose(indices)
         tshape = f.shape
-        f = f.reshape((f.shape[0],-1))
+        f = f.reshape((-1, f.shape[-1]))
 
         out = _get_output(f, out, 'convolve1d')
         _convolve.convolve1d(f, weights, out, mode2int[mode])
@@ -121,7 +122,7 @@ def convolve1d(f, weights, axis, mode='reflect', cval=0., out=None, output=None)
         index = [None] * f.ndim
         index[axis] = slice(0, None)
         weights = weights[tuple(index)]
-        return convolve(f, weights, mode=mode, cval=cval, output=output)
+        return convolve(f, weights, mode=mode, cval=cval, out=out)
 
 
 def median_filter(f, Bc=None, mode='reflect', cval=0.0, out=None, output=None):
@@ -153,6 +154,8 @@ def median_filter(f, Bc=None, mode='reflect', cval=0.0, out=None, output=None):
         Bc = np.ones((3,) * len(f.shape), f.dtype)
     elif f.dtype != Bc.dtype:
         Bc = Bc.astype(f.dtype)
+    if f.ndim != Bc.ndim:
+        raise ValueError('mahotas.median_filter: `f` and `Bc` must have the same number of dimensions')
     rank = Bc.sum()//2
     output = _get_output(f, out, 'median_filter', output=output)
     _check_mode(mode, cval, 'median_filter')
@@ -429,6 +432,7 @@ def _wavelet_array(f, inline, func):
 def _wavelet_center_compute(oshape, border=0, dtype=None, cval=0.0):
     for c in range(1, 16+border):
         nshape = 2**(np.floor(np.log2(oshape))+c)
+        nshape = nshape.astype(int)
         delta = nshape - oshape
         delta //= 2
         if np.min(delta) <= border:
@@ -637,3 +641,39 @@ def ihaar(f, preserve_energy=True, inline=False):
     if preserve_energy:
         f *= 2.0
     return f
+
+def laplacian_2D(array, alpha = 0.2):
+    """
+    filtered = laplacian_2D(array, alpha = 0.2)
+
+    2D Laplacian filter.
+
+    Parameters
+    ----------
+    array : ndarray
+        input 2D array. If the array is an integer array, it will be converted 
+        to a double array.
+    alpha : scalar or sequence of scalars
+        controls the shape of Laplacian operator. Must be 0-1. A larger values 
+        makes the operator empahsize the diagonal direction.
+
+    Returns
+    -------
+    filtered : ndarray
+        Filtered version of `array`
+    """
+    array = np.array(array, dtype=np.float)
+    if array.ndim != 2:
+        raise ValueError('mahotas.laplacian_2D: Only available for 2-dimensional arrays')
+        
+    alpha = max(0, min(alpha,1));
+    ver_hor_weight = (1. - alpha) / (alpha + 1.)
+    diag_weight = alpha / (alpha + 1.)
+    center = -4. / (alpha + 1.)
+    weights = np.array([
+    [diag_weight, ver_hor_weight, diag_weight],
+    [ver_hor_weight, center, ver_hor_weight],
+    [diag_weight, ver_hor_weight, diag_weight]])
+    
+    output = convolve(array, weights, mode='nearest')
+    return output
